% This function computes a new value for theta given the constraints t
% rootHeight is the starting height of the skeleton root
% jointOrder is a representation of the skeleton structure (see
% HumanSkeleton.m)
% initTransforms is the initial parent-space transformation of each joint
% jointLengths is the length of link
% jointAxes contains the axis about which each joint revolves
% endJoints contains the indices of joints attached to end effectors
% C(j,i) is 1 if joint j affects end effector i, 0 otherwise
% oldtheta is a vector of starting joint orientations
% t is the matrix of desired end effector positions
% render is 1 if we want to render each iteration, or 0 if we want to
% process the IK 'silently'
% Copyright Sergey Levine, 2009
function [theta] = InitialPoseHuman(rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C, oldtheta, t, render)

% Initialize helpful constants.
N = length(jointLengths);   % This is the number of joints.
K = length(endJoints);      % This is the number of end effectors.

% Initialize theta
theta = oldtheta;

% You may find the following code snippets useful:
%
% jointTransforms = ComputeMatrices(initTransforms,jointAxes,theta);
% [p,v,s] = ForwardKinematics(rootHeight,jointOrder,jointTransforms,jointLengths,jointAxes,endJoints);
%
% For the current value of theta, this computes p, the matrix of joint
% positions (where p(:,j) gives the position of the jth joint), v, the
% matrix of joint axis directions (where v(:,j) gives the axis of the jth
% joint), and s, the matrix of end effector positions (where s(:,i) gives
% the position of the ith end effector).
%
% jointTransforms = ComputeMatrices(initTransforms,jointAxes,theta);
% DrawSkeleton(rootHeight,jointOrder,jointTransforms,jointLengths,t);
%
% For the current value of theta, this draws the skeleton to the screen. If
% render == 1, this command should be called at each iteration of your
% algorithm. Otherwise, it should not be called at all.

% Draw the skeleton
if render == 1
    jointTransforms = ComputeMatrices(initTransforms,jointAxes,theta);
    DrawSkeleton(rootHeight,jointOrder,jointTransforms,jointLengths,t);
end;

% YOUR CODE HERE
