% This function plots a skeleton with the specified joint orientations
% Should not be modified
% Copyright Sergey Levine, 2009
function DrawSkeleton(rootHeight, jointOrder, jointTransforms, jointLengths, constraints)

% Begin drawing
clf
hold on

% Set up view and camera
set(gca,'Xlim',[-2 2],'Ylim',[-2 2],'Zlim',[-2 2]);
set(gca,'CameraTarget',[0 0 0.8]);
set(gca,'CameraPosition',[2 2 1.5])
set(gca,'CameraViewAngle',35);
set(gca,'Projection','perspective');
set(gca,'DataAspectRatio',[1 1 1]);

% Draw the ground plane at height 0
x=-2:.1:2;
[X,Y] = meshgrid(x);
Z=zeros(length(x));
surf(X,Y,Z)
shading faceted

% Current transformation stack
transforms = {[1,0,0,0;0,1,0,0;0,0,1,rootHeight;0,0,0,1]};

% Draw limbs
for i=1:length(jointOrder)
    % Get joint
    joint = jointOrder(i);
    % Pop transform if needed
    if joint == -1
        transforms(length(transforms)) = [];
        continue;
    end;
    % Compute joint transform
    newTransform = transforms{length(transforms)}*jointTransforms{joint};
    % Compute points
    lineStart = newTransform*[0;0;0;1];
    lineEnd = newTransform*[0;0;jointLengths(joint);1];
    x = [lineStart(1),lineEnd(1)];
    y = [lineStart(2),lineEnd(2)];
    z = [lineStart(3),lineEnd(3)];
    % Push new transform
    transforms{length(transforms)+1} = newTransform*[1,0,0,0;0,1,0,0;0,0,1,jointLengths(joint);0,0,0,1];
    
    p1 = plot3(x,y,z);
    set(p1,'LineWidth',2);
    p1j = plot3(x,y,z,'o');
    set(p1j,'Color',[0,0.75,0.5],'LineWidth',2);
end;

% Plot constraint positions
c = plot3(constraints(1,:),constraints(2,:),constraints(3,:),'o');
set(c,'Color',[1.0,0.0,0.0],'LineWidth',3);

% End drawing
hold off
drawnow
