% This function returns joint positions given skeleton parameters and
% current transformations.
% Should not be modified
% Copyright Sergey Levine, 2009
function [p,v,s] = ForwardKinematics(rootHeight, jointOrder, jointTransforms, jointLengths, jointAxes, endJoints)

% Current transformation stack
transforms = {[1,0,0,0;0,1,0,0;0,0,1,rootHeight;0,0,0,1]};

% Initialize joint positions.
p = zeros(3,length(jointLengths));

% Initialize joint axes.
v = zeros(3,length(jointLengths));

% Initialize end effector positions.
s = zeros(3,length(endJoints));

% Index of last end joint.
lastEnd = 1;

% Draw limbs
for i=1:length(jointOrder)
    % Get joint
    joint = jointOrder(i);
    % Pop transform if needed
    if joint == -1
        transforms(length(transforms)) = [];
        continue;
    end;
    % Compute joint transform
    newTransform = transforms{length(transforms)}*jointTransforms{joint};
    % Compute rotational component
    rot = newTransform(1:3,1:3);
    % Compute joint axis.
    if jointAxes(joint) == 'x'
        v(:,joint) = rot*[1;0;0];
    elseif jointAxes(joint) == 'y'
        v(:,joint) = rot*[0;1;0];
    elseif jointAxes(joint) == 'z'
        v(:,joint) = rot*[0;0;1];
    end;
    % Compute position
    point = newTransform*[0;0;0;1];
    % Push new transform
    transforms{length(transforms)+1} = newTransform*[1,0,0,0;0,1,0,0;0,0,1,jointLengths(joint);0,0,0,1];
    % Store point
    p(:,joint) = point(1:3);
    % Test if we need to compute end effector here.
    if lastEnd <= length(endJoints) && joint == endJoints(lastEnd),
        % Compute position.
        point = transforms{length(transforms)}*[0;0;0;1];
        s(:,lastEnd) = point(1:3);
        % Increment last end joint index.
        lastEnd = lastEnd + 1;
    end;
end;
