% This function creates a human skeleton.
% Should not be modified
% Copyright Sergey Levine, 2009
function [rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C] = HumanSkeleton()

% Initialize skeleton and initial position.
% Height of the root above the ground.
rootHeight = 0.7;
% Order of joints for tree traversal.
% -1 pops the transformation stack (it is not necessary to understand this
% for the assignment - if curious, e-mail me svlevine@stanford.edu).
jointOrder = [1,2,3,4,-1,5,6,7,8,-1,-1,-1,-1,9,10,11,12,-1,-1,-1,-1,-1,-1,-1,13,14,15,16,-1,-1,-1,-1,17,18,19,20];
% Parent-space initial transformations of each joint.
initTransforms =  {Rotation(''),            % 1  body (forward/backward)
                   Rotation(''),            % 2  body (side to side)
                   Rotation(''),            % 3  body (twist)
                   Rotation(''),            % 4  head
                   Rotation('x',pi*0.5),    % 5  l shoulder (swing)
                   Rotation('x',pi*0.5),    % 6  l shoulder (open/close)
                   Rotation(''),            % 7  l shoulder (twist)
                   Rotation(''),            % 8  l elbow
                   Rotation('x',-pi*0.5),   % 9  r shoulder (swing)
                   Rotation('x',-pi*0.5),   % 10 r shoulder (open/close)
                   Rotation(''),            % 11 r shoulder (twist)
                   Rotation(''),            % 12 r elbow
                   Rotation('x',pi*0.5),    % 13 l hip (swing)
                   Rotation('x',pi*0.5),	% 14 l hip (open/close)
                   Rotation(''),            % 15 l hip (twist)
                   Rotation(''),            % 16 l knee
                   Rotation('x',-pi*0.5),   % 17 r hip (swing)
                   Rotation('x',-pi*0.5),	% 18 r hip (open/close)
                   Rotation(''),            % 19 r hip (twist)
                   Rotation('')};           % 20 r knee
% Link length of each joint.
jointLengths = [0.0,0.0,0.4,0.2,0.15,0.0,0.3,0.3,0.15,0.0,0.3,0.3,0.1,0.0,0.4,0.4,0.1,0.0,0.4,0.4];
% Axis about which each joint revolves (in parent space).
jointAxes = ['y','x','z','y','z','x','z','y','z','x','z','y','z','x','z','y','z','x','z','y'];
% Indices of joints that have end effectors at their ends.
endJoints = [8,12,16,20];
% Matrix indicating which joint affects which end effector (see Jacobian.m).
C = ComputeRelation(jointOrder, length(jointLengths), endJoints);
