% Create the skeleton
[rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C] = HumanSkeleton();

% Set initial position
theta0 = InitialPoseHuman(rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C);

% Create constraints
% First frame - prepare kick
t1 = [0.0,0.15,0.56;
      0.0,-0.15,0.56;
      0.0,0.1,0.0;
      -0.2,0.2,0.6];
% Second frame - kick
t2 = [0.0,0.15,0.56;
      0.0,-0.15,0.56;
      0.0,0.1,0.0;
      0.3,-0.3,0.7];
% Third frame - done
t3 = [0.0,0.15,0.56;
      0.0,-0.15,0.56;
      0.0,0.1,0.0;
      0.0,-0.1,0.5];
t1 = t1';
t2 = t2';
t3 = t3';
  
% Precompute IK
theta1 = ComputeIK(rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C, theta0, t1, 1);
theta2 = ComputeIK(rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C, theta1, t2, 1);
theta3 = ComputeIK(rootHeight, jointOrder, initTransforms, jointLengths, jointAxes, endJoints, C, theta2, t3, 1);

% Draw the animation using interpolation
% First interpolate between t1 and t2
for i=1:20
    % Compute theta for this frame
    theta = InterpolateFrame(theta1,theta2,i/20);
    % Draw the skeleton
    jointTransforms = ComputeMatrices(initTransforms,jointAxes,theta);
    DrawSkeleton(rootHeight,jointOrder,jointTransforms,jointLengths,t2);
end;
% Then interpolate between t2 and t3
for i=1:20
    % Compute theta for this frame
    theta = InterpolateFrame(theta2,theta3,i/20);
    % Draw the skeleton
    jointTransforms = ComputeMatrices(initTransforms,jointAxes,theta);
    DrawSkeleton(rootHeight,jointOrder,jointTransforms,jointLengths,t3);
end;
